@@ -6,7 +6,7 @@ from pyspark.sql.dataframe import DataFrame
 
 import unittest
 
-class TestCaseFact(unittest.TestCase):
+class FactTestCase(unittest.TestCase):
 
     #region Constructor
 
